# auto_rxn

[![PyPI](https://img.shields.io/pypi/v/auto_rxn)](https://pypi.org/project/auto_rxn)
[![Conda](https://img.shields.io/conda/vn/conda-forge/auto_rxn)](https://anaconda.org/conda-forge/auto_rxn)
[![log](https://img.shields.io/badge/change-log-informational)](https://github.com/uw-madison-chem-shops/auto_rxn/blob/main/CHANGELOG.md#changelog)

Python package for running chemical reactions as defined by "recipe" files.

Documentation at https://uw-madison-chem-shops.github.io/auto_rxn/

